@@ -25,7 +25,6 @@
 
 #include <QGraphicsObject>
 #include <QTextDocument>
-#include <QObject>
 #include "sector.h"
 
 class Game;
@@ -39,21 +38,21 @@ public:
     explicit PlanetItem(MapScene *scene, Sector *sector, Game *game);
     ~PlanetItem() {}
 
-    QRectF   boundingRect() const;
+    QRectF   boundingRect() const override;
     void     paint(QPainter *painter, const QStyleOptionGraphicsItem *option,
-                   QWidget *widget);
+                   QWidget *widget) override;
 
-    void     hoverEnterEvent ( QGraphicsSceneHoverEvent *event );
-    void     hoverLeaveEvent ( QGraphicsSceneHoverEvent *event );
-    void     mousePressEvent ( QGraphicsSceneMouseEvent *event );
+    void     hoverEnterEvent ( QGraphicsSceneHoverEvent *event ) override;
+    void     hoverLeaveEvent ( QGraphicsSceneHoverEvent *event ) override;
+    void     mousePressEvent ( QGraphicsSceneMouseEvent *event ) override;
     void     unselect ();
     void     select ();
     Sector  *sector () { return m_sector; }
 
-signals:
+Q_SIGNALS:
     void     planetItemSelected (PlanetItem *);
 
-private slots:
+private:
     void     updatePlanet ();
     void     blinkPlanet ();
 
@@ -79,11 +78,11 @@ public:
     explicit PlanetInfoItem(Game*);
     ~PlanetInfoItem() {}
 
-    QRectF   boundingRect() const;
+    QRectF   boundingRect() const override;
     void     setPlanet (Planet *planet);
     Planet  *planet () { return m_planet; }
     void     paint(QPainter *painter, const QStyleOptionGraphicsItem *option,
-                   QWidget *widget);
+                   QWidget *widget) override;
 
 private:
     Game          *m_game;
